==> icedtea-web-1.4.2.tar.gz: icedtea-web-1.4.2/tests/reproducers/custom/JNLPClassLoaderDeadlock/testcases/JNLPClassLoaderDeadlockTest.java <==
/* JNLPClassLoaderDeadlockTest.java
Copyright (C) 2013 Red Hat, Inc.

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as published by
the Free Software Foundation, version 2.

IcedTea is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
 */

import net.sourceforge.jnlp.ProcessResult;
import net.sourceforge.jnlp.ServerAccess.AutoClose;
import net.sourceforge.jnlp.annotations.Bug;
import net.sourceforge.jnlp.annotations.KnownToFail;
import net.sourceforge.jnlp.annotations.NeedsDisplay;
import net.sourceforge.jnlp.annotations.TestInBrowsers;
import net.sourceforge.jnlp.browsertesting.BrowserTest;
import net.sourceforge.jnlp.browsertesting.Browsers;
import net.sourceforge.jnlp.closinglisteners.AutoOkClosingListener;

import static org.junit.Assert.assertTrue;
import org.junit.Test;

public class JNLPClassLoaderDeadlockTest extends BrowserTest {

    @NeedsDisplay
    @Test
    @TestInBrowsers(testIn={Browsers.one})
    @Bug(id="RH976833")
    public void testClassLoaderDeadlock() throws Exception {
        ProcessResult pr = server.executeBrowser("JNLPClassLoaderDeadlock.html", AutoClose.CLOSE_ON_CORRECT_END);
        assertTrue("First applet should have initialized",
                pr.stdout.contains("JNLPClassLoaderDeadlock_1 applet initialized"));
        assertTrue("Second applet should have initialized",
                pr.stdout.contains("JNLPClassLoaderDeadlock_2 applet initialized"));

        assertTrue("First applet should have finished",
                pr.stdout.contains("JNLPClassLoaderDeadlock_1 applet finished"));
        assertTrue("Second applet should have finished",
                pr.stdout.contains("JNLPClassLoaderDeadlock_2 applet finished"));
    }

}

==> icedtea-web_1.6.2.orig.tar.gz: icedtea-web-1.6.2/tests/reproducers/custom/JNLPClassLoaderDeadlock/testcases/JNLPClassLoaderDeadlockTest.java <==
/* JNLPClassLoaderDeadlockTest.java
Copyright (C) 2013 Red Hat, Inc.

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as published by
the Free Software Foundation, version 2.

IcedTea is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
 */

import net.sourceforge.jnlp.ProcessResult;
import net.sourceforge.jnlp.ServerAccess.AutoClose;
import net.sourceforge.jnlp.annotations.Bug;
import net.sourceforge.jnlp.annotations.KnownToFail;
import net.sourceforge.jnlp.annotations.NeedsDisplay;
import net.sourceforge.jnlp.annotations.TestInBrowsers;
import net.sourceforge.jnlp.browsertesting.BrowserTest;
import net.sourceforge.jnlp.browsertesting.Browsers;
import net.sourceforge.jnlp.closinglisteners.RulesFolowingClosingListener;

import static org.junit.Assert.assertTrue;
import org.junit.Test;

public class JNLPClassLoaderDeadlockTest extends BrowserTest {

    @NeedsDisplay
    @Test
    @TestInBrowsers(testIn={Browsers.one})
    @Bug(id="RH976833")
    public void testClassLoaderDeadlock() throws Exception {
        RulesFolowingClosingListener listener = new RulesFolowingClosingListener();
        listener.addContainsRule("JNLPClassLoaderDeadlock_1 applet finished");
        listener.addContainsRule("JNLPClassLoaderDeadlock_2 applet finished");
        ProcessResult pr = server.executeBrowser("JNLPClassLoaderDeadlock.html", listener, null);
        assertTrue("First applet should have initialized",
                pr.stdout.contains("JNLPClassLoaderDeadlock_1 applet initialized"));
        assertTrue("Second applet should have initialized",
                pr.stdout.contains("JNLPClassLoaderDeadlock_2 applet initialized"));

        assertTrue("First applet should have finished",
                pr.stdout.contains("JNLPClassLoaderDeadlock_1 applet finished"));
        assertTrue("Second applet should have finished",
                pr.stdout.contains("JNLPClassLoaderDeadlock_2 applet finished"));
    }

}
